pub struct GetEdgarFilingsArchiveParams {
pub symbol: Option<String>,
pub figi: Option<String>,
pub isin: Option<String>,
pub cusip: Option<String>,
pub exchange: Option<String>,
pub mic_code: Option<String>,
pub country: Option<String>,
pub form_type: Option<String>,
pub filled_from: Option<String>,
pub filled_to: Option<String>,
pub page: Option<i64>,
pub page_size: Option<i64>,
}Expand description
struct for passing parameters to the method get_edgar_filings_archive
Fields
symbol: Option<String>The ticker symbol of an instrument for which data is requested
figi: Option<String>Filter by financial instrument global identifier (FIGI)
isin: Option<String>Filter by international securities identification number (ISIN)
cusip: Option<String>The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
exchange: Option<String>Filter by exchange name
mic_code: Option<String>Filter by market identifier code (MIC) under ISO 10383 standard
country: Option<String>Filter by country name or alpha code, e.g., United States or US
form_type: Option<String>Filter by form types, example 8-K, EX-1.1
filled_from: Option<String>Filter by filled time from
filled_to: Option<String>Filter by filled time to
page: Option<i64>Page number
page_size: Option<i64>Number of records in response
Implementations
Sourceimpl GetEdgarFilingsArchiveParams
impl GetEdgarFilingsArchiveParams
Sourcepub fn builder() -> GetEdgarFilingsArchiveParamsBuilder
pub fn builder() -> GetEdgarFilingsArchiveParamsBuilder
Create a new builder for this parameter struct