pub struct GetRecommendationsParams {
pub symbol: Option<String>,
pub figi: Option<String>,
pub isin: Option<String>,
pub cusip: Option<String>,
pub country: Option<String>,
pub exchange: Option<String>,
}Expand description
struct for passing parameters to the method get_recommendations
Fields
symbol: Option<String>Filter by symbol
figi: Option<String>The FIGI of an instrument for which data is requested
isin: Option<String>Filter by international securities identification number (ISIN)
cusip: Option<String>The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
country: Option<String>The country where the instrument is traded, e.g., United States or US
exchange: Option<String>The exchange name where the instrument is traded, e.g., Nasdaq, NSE.
Implementations
Sourceimpl GetRecommendationsParams
impl GetRecommendationsParams
Sourcepub fn builder() -> GetRecommendationsParamsBuilder
pub fn builder() -> GetRecommendationsParamsBuilder
Create a new builder for this parameter struct