pub struct GetRecommendationsParamsBuilder { /* private fields */ }Expand description
Builder for GetRecommendationsParams
Implementations
Sourceimpl GetRecommendationsParamsBuilder
impl GetRecommendationsParamsBuilder
Sourcepub fn figi(self, figi: impl Into<String>) -> Self
pub fn figi(self, figi: impl Into<String>) -> Self
The FIGI of an instrument for which data is requested
Sourcepub fn isin(self, isin: impl Into<String>) -> Self
pub fn isin(self, isin: impl Into<String>) -> Self
Filter by international securities identification number (ISIN)
Sourcepub fn cusip(self, cusip: impl Into<String>) -> Self
pub fn cusip(self, cusip: impl Into<String>) -> Self
The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
The country where the instrument is traded, e.g., United States or US
Sourcepub fn exchange(self, exchange: impl Into<String>) -> Self
pub fn exchange(self, exchange: impl Into<String>) -> Self
The exchange name where the instrument is traded, e.g., Nasdaq, NSE.
Sourcepub fn build(self) -> GetRecommendationsParams
pub fn build(self) -> GetRecommendationsParams
Build the parameter struct