pub struct GetIncomeStatementParams {
pub symbol: Option<String>,
pub figi: Option<String>,
pub isin: Option<String>,
pub cusip: Option<String>,
pub exchange: Option<String>,
pub mic_code: Option<String>,
pub country: Option<String>,
pub period: Option<String>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub outputsize: Option<i64>,
}Expand description
struct for passing parameters to the method get_income_statement
Fields
symbol: Option<String>Symbol ticker of instrument. For preffered stocks use dot(.) delimiter. E.g. BRK.A or BRK.B will be correct
figi: Option<String>Filter by financial instrument global identifier (FIGI)
isin: Option<String>Filter by international securities identification number (ISIN)
cusip: Option<String>The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
exchange: Option<String>Exchange where instrument is traded
mic_code: Option<String>Market Identifier Code (MIC) under ISO 10383 standard
country: Option<String>Country where instrument is traded, e.g., United States or US
period: Option<String>The reporting period for the income statement data
start_date: Option<String>Begin date for filtering income statements by fiscal date. Returns income statements with fiscal dates on or after this date. Format 2006-01-02
end_date: Option<String>End date for filtering income statements by fiscal date. Returns income statements with fiscal dates on or before this date. Format 2006-01-02
outputsize: Option<i64>Number of records in response
Implementations
Sourceimpl GetIncomeStatementParams
impl GetIncomeStatementParams
Sourcepub fn builder() -> GetIncomeStatementParamsBuilder
pub fn builder() -> GetIncomeStatementParamsBuilder
Create a new builder for this parameter struct