pub struct GetSplitsCalendarParams {
pub symbol: Option<String>,
pub figi: Option<String>,
pub isin: Option<String>,
pub cusip: Option<String>,
pub exchange: Option<String>,
pub mic_code: Option<String>,
pub country: Option<String>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub outputsize: Option<i64>,
pub page: Option<String>,
}Expand description
struct for passing parameters to the method get_splits_calendar
Fields
symbol: Option<String>Symbol ticker of instrument. For preffered stocks use dot(.) delimiter. E.g. BRK.A or BRK.B will be correct
figi: Option<String>Filter by financial instrument global identifier (FIGI)
isin: Option<String>Filter by international securities identification number (ISIN)
cusip: Option<String>The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
exchange: Option<String>Exchange where instrument is traded
mic_code: Option<String>Market Identifier Code (MIC) under ISO 10383 standard
country: Option<String>Country where instrument is traded, e.g., United States or US
start_date: Option<String>The starting date (inclusive) for filtering split events in the calendar. Format 2006-01-02
end_date: Option<String>The ending date (inclusive) for filtering split events in the calendar. Format 2006-01-02
outputsize: Option<i64>Number of data points to retrieve. Supports values in the range from 1 to 500. Default 100 when no date parameters are set, otherwise set to maximum
page: Option<String>Page number
Implementations
Sourceimpl GetSplitsCalendarParams
impl GetSplitsCalendarParams
Sourcepub fn builder() -> GetSplitsCalendarParamsBuilder
pub fn builder() -> GetSplitsCalendarParamsBuilder
Create a new builder for this parameter struct