get_bonds

Function get_bonds 

pub async fn get_bonds(
    configuration: &Configuration,
    params: GetBondsParams,
) -> Result<GetBonds200Response, Error<GetBondsError>>
The fixed income endpoint provides a daily updated list of available bonds. It returns an array containing detailed information about each bond, including identifiers, names, and other relevant attributes.