pub async fn get_commodities(
configuration: &Configuration,
params: GetCommoditiesParams,
) -> Result<GetCommoditiesResponse, Error<GetCommoditiesError>>Expand description
The commodities endpoint provides a daily updated list of available commodity pairs, across precious metals, livestock, softs, grains, etc.