pub async fn get_intervals(
configuration: &Configuration,
) -> Result<GetIntervalsResponse, Error<GetIntervalsError>>Expand description
The intervals endpoint provides a list of supported time intervals that can be used for querying financial data.