pub struct GetBondsParams {
pub symbol: Option<String>,
pub exchange: Option<String>,
pub country: Option<String>,
pub format: Option<String>,
pub delimiter: Option<String>,
pub show_plan: Option<bool>,
pub page: Option<i64>,
pub outputsize: Option<i64>,
}Expand description
struct for passing parameters to the method get_bonds
Fields
symbol: Option<String>The ticker symbol of an instrument for which data is requested
exchange: Option<String>Filter by exchange name
country: Option<String>Filter by country name or alpha code, e.g., United States or US
format: Option<String>The format of the response data
delimiter: Option<String>The separator used in the CSV response data
show_plan: Option<bool>Adds info on which plan symbol is available
page: Option<i64>Page number of the results to fetch
outputsize: Option<i64>Determines the number of data points returned in the output
Implementations
Sourceimpl GetBondsParams
impl GetBondsParams
Sourcepub fn builder() -> GetBondsParamsBuilder
pub fn builder() -> GetBondsParamsBuilder
Create a new builder for this parameter struct