pub struct GetBondsParamsBuilder { /* private fields */ }Expand description
Builder for GetBondsParams
Implementations
Sourceimpl GetBondsParamsBuilder
impl GetBondsParamsBuilder
Sourcepub fn symbol(self, symbol: impl Into<String>) -> Self
pub fn symbol(self, symbol: impl Into<String>) -> Self
The ticker symbol of an instrument for which data is requested
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
Filter by country name or alpha code, e.g., United States or US
Sourcepub fn delimiter(self, delimiter: impl Into<String>) -> Self
pub fn delimiter(self, delimiter: impl Into<String>) -> Self
The separator used in the CSV response data
Sourcepub fn outputsize(self, outputsize: i64) -> Self
pub fn outputsize(self, outputsize: i64) -> Self
Determines the number of data points returned in the output
Sourcepub fn build(self) -> GetBondsParams
pub fn build(self) -> GetBondsParams
Build the parameter struct