pub struct GetEtfParamsBuilder { /* private fields */ }Expand description
Builder for GetEtfParams
Implementations
Sourceimpl GetEtfParamsBuilder
impl GetEtfParamsBuilder
Sourcepub fn symbol(self, symbol: impl Into<String>) -> Self
pub fn symbol(self, symbol: impl Into<String>) -> Self
The ticker symbol of an instrument for which data is requested
Sourcepub fn figi(self, figi: impl Into<String>) -> Self
pub fn figi(self, figi: impl Into<String>) -> Self
Filter by financial instrument global identifier (FIGI)
Sourcepub fn isin(self, isin: impl Into<String>) -> Self
pub fn isin(self, isin: impl Into<String>) -> Self
Filter by international securities identification number (ISIN)
Sourcepub fn cusip(self, cusip: impl Into<String>) -> Self
pub fn cusip(self, cusip: impl Into<String>) -> Self
The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
Sourcepub fn cik(self, cik: impl Into<String>) -> Self
pub fn cik(self, cik: impl Into<String>) -> Self
The CIK of an instrument for which data is requested
Sourcepub fn mic_code(self, mic_code: impl Into<String>) -> Self
pub fn mic_code(self, mic_code: impl Into<String>) -> Self
Filter by market identifier code (MIC) under ISO 10383 standard
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
Filter by country name or alpha code, e.g., United States or US
Sourcepub fn delimiter(self, delimiter: impl Into<String>) -> Self
pub fn delimiter(self, delimiter: impl Into<String>) -> Self
The separator used in the CSV response data
Sourcepub fn include_delisted(self, include_delisted: bool) -> Self
pub fn include_delisted(self, include_delisted: bool) -> Self
Include delisted identifiers
Sourcepub fn build(self) -> GetEtfParams
pub fn build(self) -> GetEtfParams
Build the parameter struct