pub struct GetExchangeScheduleParams {
pub mic_name: Option<String>,
pub mic_code: Option<String>,
pub country: Option<String>,
pub date: Option<String>,
}Expand description
struct for passing parameters to the method get_exchange_schedule
Fields
mic_name: Option<String>Filter by exchange name
mic_code: Option<String>Filter by market identifier code (MIC) under ISO 10383 standard
country: Option<String>Filter by country name or alpha code, e.g., United States or US
date: Option<String>If a date is provided, the API returns the schedule for the specified date; otherwise, it returns the default (common) schedule.
The date can be specified in one of the following formats:- An exact date (e.g.,
2021-10-27) - A human-readable keyword:
todayoryesterday - A full datetime string in UTC (e.g.,
2025-04-11T20:00:00) to retrieve the schedule corresponding to the day in the specified time.
2025-04-11T20:00:00 UTC corresponds to: 2025-04-11in theAmerica/New_Yorktimezone2025-04-12in theAustralia/Sydneytimezone
Implementations
Sourceimpl GetExchangeScheduleParams
impl GetExchangeScheduleParams
Sourcepub fn builder() -> GetExchangeScheduleParamsBuilder
pub fn builder() -> GetExchangeScheduleParamsBuilder
Create a new builder for this parameter struct