pub struct GetExchangeScheduleParamsBuilder { /* private fields */ }Expand description
Builder for GetExchangeScheduleParams
Implementations
Sourceimpl GetExchangeScheduleParamsBuilder
impl GetExchangeScheduleParamsBuilder
Sourcepub fn mic_code(self, mic_code: impl Into<String>) -> Self
pub fn mic_code(self, mic_code: impl Into<String>) -> Self
Filter by market identifier code (MIC) under ISO 10383 standard
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
Filter by country name or alpha code, e.g., United States or US
Sourcepub fn date(self, date: impl Into<String>) -> Self
pub fn date(self, date: impl Into<String>) -> Self
If a date is provided, the API returns the schedule for the specified date; otherwise, it returns the default (common) schedule.
The date can be specified in one of the following formats:- An exact date (e.g.,
2021-10-27) - A human-readable keyword:
todayoryesterday - A full datetime string in UTC (e.g.,
2025-04-11T20:00:00) to retrieve the schedule corresponding to the day in the specified time.
2025-04-11T20:00:00 UTC corresponds to: 2025-04-11in theAmerica/New_Yorktimezone2025-04-12in theAustralia/Sydneytimezone
Sourcepub fn build(self) -> GetExchangeScheduleParams
pub fn build(self) -> GetExchangeScheduleParams
Build the parameter struct