pub struct GetFundsParamsBuilder { /* private fields */ }Expand description
Builder for GetFundsParams
Implementations
Sourceimpl GetFundsParamsBuilder
impl GetFundsParamsBuilder
Sourcepub fn symbol(self, symbol: impl Into<String>) -> Self
pub fn symbol(self, symbol: impl Into<String>) -> Self
The ticker symbol of an instrument for which data is requested
Sourcepub fn figi(self, figi: impl Into<String>) -> Self
pub fn figi(self, figi: impl Into<String>) -> Self
Filter by financial instrument global identifier (FIGI)
Sourcepub fn isin(self, isin: impl Into<String>) -> Self
pub fn isin(self, isin: impl Into<String>) -> Self
Filter by international securities identification number (ISIN)
Sourcepub fn cusip(self, cusip: impl Into<String>) -> Self
pub fn cusip(self, cusip: impl Into<String>) -> Self
The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
Sourcepub fn cik(self, cik: impl Into<String>) -> Self
pub fn cik(self, cik: impl Into<String>) -> Self
The CIK of an instrument for which data is requested
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
Filter by country name or alpha code, e.g., United States or US
Sourcepub fn delimiter(self, delimiter: impl Into<String>) -> Self
pub fn delimiter(self, delimiter: impl Into<String>) -> Self
The separator used in the CSV response data
Sourcepub fn outputsize(self, outputsize: i64) -> Self
pub fn outputsize(self, outputsize: i64) -> Self
Determines the number of data points returned in the output
Sourcepub fn build(self) -> GetFundsParams
pub fn build(self) -> GetFundsParams
Build the parameter struct