pub struct GetMutualFundsListParams {
pub symbol: Option<String>,
pub figi: Option<String>,
pub isin: Option<String>,
pub cusip: Option<String>,
pub cik: Option<String>,
pub country: Option<String>,
pub fund_family: Option<String>,
pub fund_type: Option<String>,
pub performance_rating: Option<i64>,
pub risk_rating: Option<i64>,
pub page: Option<i64>,
pub outputsize: Option<i64>,
}Expand description
struct for passing parameters to the method get_mutual_funds_list
Fields
symbol: Option<String>Filter by symbol
figi: Option<String>Filter by financial instrument global identifier (FIGI)
isin: Option<String>Filter by international securities identification number (ISIN)
cusip: Option<String>The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
cik: Option<String>The CIK of an instrument for which data is requested
country: Option<String>Filter by country name or alpha code, e.g., United States or US
fund_family: Option<String>Filter by investment company that manages the fund
fund_type: Option<String>Filter by the type of fund
performance_rating: Option<i64>Filter by performance rating from 0 to 5
risk_rating: Option<i64>Filter by risk rating from 0 to 5
page: Option<i64>Page number
outputsize: Option<i64>Number of records in response
Implementations
Sourceimpl GetMutualFundsListParams
impl GetMutualFundsListParams
Sourcepub fn builder() -> GetMutualFundsListParamsBuilder
pub fn builder() -> GetMutualFundsListParamsBuilder
Create a new builder for this parameter struct