pub struct GetMutualFundsListParamsBuilder { /* private fields */ }Expand description
Builder for GetMutualFundsListParams
Implementations
Sourceimpl GetMutualFundsListParamsBuilder
impl GetMutualFundsListParamsBuilder
Sourcepub fn figi(self, figi: impl Into<String>) -> Self
pub fn figi(self, figi: impl Into<String>) -> Self
Filter by financial instrument global identifier (FIGI)
Sourcepub fn isin(self, isin: impl Into<String>) -> Self
pub fn isin(self, isin: impl Into<String>) -> Self
Filter by international securities identification number (ISIN)
Sourcepub fn cusip(self, cusip: impl Into<String>) -> Self
pub fn cusip(self, cusip: impl Into<String>) -> Self
The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
Sourcepub fn cik(self, cik: impl Into<String>) -> Self
pub fn cik(self, cik: impl Into<String>) -> Self
The CIK of an instrument for which data is requested
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
Filter by country name or alpha code, e.g., United States or US
Sourcepub fn fund_family(self, fund_family: impl Into<String>) -> Self
pub fn fund_family(self, fund_family: impl Into<String>) -> Self
Filter by investment company that manages the fund
Sourcepub fn performance_rating(self, performance_rating: i64) -> Self
pub fn performance_rating(self, performance_rating: i64) -> Self
Filter by performance rating from 0 to 5
Sourcepub fn risk_rating(self, risk_rating: i64) -> Self
pub fn risk_rating(self, risk_rating: i64) -> Self
Filter by risk rating from 0 to 5
Sourcepub fn outputsize(self, outputsize: i64) -> Self
pub fn outputsize(self, outputsize: i64) -> Self
Number of records in response
Sourcepub fn build(self) -> GetMutualFundsListParams
pub fn build(self) -> GetMutualFundsListParams
Build the parameter struct