pub struct GetTimeSeriesMacdExtParamsBuilder { /* private fields */ }Expand description
Builder for GetTimeSeriesMacdExtParams
Implementations
Sourceimpl GetTimeSeriesMacdExtParamsBuilder
impl GetTimeSeriesMacdExtParamsBuilder
Sourcepub fn interval(self, interval: impl Into<String>) -> Self
pub fn interval(self, interval: impl Into<String>) -> Self
Interval between two consecutive points in time series
Sourcepub fn symbol(self, symbol: impl Into<String>) -> Self
pub fn symbol(self, symbol: impl Into<String>) -> Self
Symbol ticker of the instrument. E.g. AAPL, EUR/USD, ETH/BTC, …
Sourcepub fn isin(self, isin: impl Into<String>) -> Self
pub fn isin(self, isin: impl Into<String>) -> Self
Filter by international securities identification number (ISIN)
Sourcepub fn figi(self, figi: impl Into<String>) -> Self
pub fn figi(self, figi: impl Into<String>) -> Self
The FIGI of an instrument for which data is requested
Sourcepub fn cusip(self, cusip: impl Into<String>) -> Self
pub fn cusip(self, cusip: impl Into<String>) -> Self
The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
Sourcepub fn outputsize(self, outputsize: i64) -> Self
pub fn outputsize(self, outputsize: i64) -> Self
Number of data points to retrieve. Supports values in the range from 1 to 5000. Default 30 when no date parameters are set, otherwise set to maximum
Sourcepub fn mic_code(self, mic_code: impl Into<String>) -> Self
pub fn mic_code(self, mic_code: impl Into<String>) -> Self
Market Identifier Code (MIC) under ISO 10383 standard
Sourcepub fn country(self, country: impl Into<String>) -> Self
pub fn country(self, country: impl Into<String>) -> Self
The country where the instrument is traded, e.g., United States or US
Sourcepub fn type(self, type: impl Into<String>) -> Self
pub fn type(self, type: impl Into<String>) -> Self
The asset class to which the instrument belongs
Sourcepub fn timezone(self, timezone: impl Into<String>) -> Self
pub fn timezone(self, timezone: impl Into<String>) -> Self
Timezone at which output datetime will be displayed. Supports:
- 1.
Exchangefor local exchange time - 2.
UTCfor datetime at universal UTC standard - 3. Timezone name according to the IANA Time Zone Database. E.g.
America/New_York,Asia/Singapore. Full list of timezones can be found <a href="https://en.wikipedia.org/wiki/List_of_tz_database_time_zones" target="blank">here
Sourcepub fn start_date(self, start_date: impl Into<String>) -> Self
pub fn start_date(self, start_date: impl Into<String>) -> Self
Can be used separately and together with end_date. Format 2006-01-02 or 2006-01-02T15:04:05 Default location:
- Forex and Cryptocurrencies -
UTC - Stocks - where exchange is located (e.g. for AAPL it will be
America/New_York)
timezone parameter is provided.If
timezone is given then, start_date and end_date will be used in the specified location Examples: - 1.
&symbol=AAPL&start_date=2019-08-09T15:50:00&…
Returns all records starting from 2019-08-09T15:50:00 New York time up to current date - 2.
&symbol=EUR/USD&timezone=Asia/Singapore&start_date=2019-08-09T15:50:00&…
Returns all records starting from 2019-08-09T15:50:00 Singapore time up to current date - 3.
&symbol=ETH/BTC&timezone=Europe/Zurich&start_date=2019-08-09T15:50:00&end_date=2019-08-09T15:55:00&…
Returns all records starting from 2019-08-09T15:50:00 Zurich time up to 2019-08-09T15:55:00
Sourcepub fn end_date(self, end_date: impl Into<String>) -> Self
pub fn end_date(self, end_date: impl Into<String>) -> Self
The ending date and time for data selection, see start_date description for details.
Sourcepub fn date(self, date: impl Into<String>) -> Self
pub fn date(self, date: impl Into<String>) -> Self
Specifies the exact date to get the data for. Could be the exact date, e.g. 2021-10-27, or in human language today or yesterday
Sourcepub fn prepost(self, prepost: bool) -> Self
pub fn prepost(self, prepost: bool) -> Self
Returns quotes that include pre-market and post-market data. Only for Pro and above plans. Available at the 1min, 5min, 15min, and 30min intervals for US equities. Open, high, low, close values are supplied without volume
Sourcepub fn delimiter(self, delimiter: impl Into<String>) -> Self
pub fn delimiter(self, delimiter: impl Into<String>) -> Self
The separator used in the CSV response data
Sourcepub fn dp(self, dp: i64) -> Self
pub fn dp(self, dp: i64) -> Self
Specifies the number of decimal places for floating values. Should be in range [0, 11] inclusive. By default, the number of decimal places is automatically determined based on the values provided
Sourcepub fn previous_close(self, previous_close: bool) -> Self
pub fn previous_close(self, previous_close: bool) -> Self
A boolean parameter to include the previous closing price in the time_series data. If true, adds previous bar close price value to the current object
Sourcepub fn series_type(self, series_type: impl Into<String>) -> Self
pub fn series_type(self, series_type: impl Into<String>) -> Self
Price type on which technical indicator is calculated
Sourcepub fn fast_period(self, fast_period: i64) -> Self
pub fn fast_period(self, fast_period: i64) -> Self
Number of periods for fast moving average. Takes values in the range from 1 to 800
Sourcepub fn fast_ma_type(self, fast_ma_type: impl Into<String>) -> Self
pub fn fast_ma_type(self, fast_ma_type: impl Into<String>) -> Self
The type of fast moving average used in the calculation.
Sourcepub fn slow_period(self, slow_period: i64) -> Self
pub fn slow_period(self, slow_period: i64) -> Self
Number of periods for slow moving average. Takes values in the range from 1 to 800
Sourcepub fn slow_ma_type(self, slow_ma_type: impl Into<String>) -> Self
pub fn slow_ma_type(self, slow_ma_type: impl Into<String>) -> Self
The type of slow moving average used in the calculation.
Sourcepub fn signal_period(self, signal_period: i64) -> Self
pub fn signal_period(self, signal_period: i64) -> Self
The time period used for generating the signal line.
Sourcepub fn signal_ma_type(self, signal_ma_type: impl Into<String>) -> Self
pub fn signal_ma_type(self, signal_ma_type: impl Into<String>) -> Self
The type of fast moving average used for generating the signal line.
Sourcepub fn include_ohlc(self, include_ohlc: bool) -> Self
pub fn include_ohlc(self, include_ohlc: bool) -> Self
Specify if OHLC values should be added in the output
Sourcepub fn build(self) -> GetTimeSeriesMacdExtParams
pub fn build(self) -> GetTimeSeriesMacdExtParams
Build the parameter struct