pub struct GetTimeSeriesMinParams {Show 24 fields
pub interval: String,
pub symbol: Option<String>,
pub isin: Option<String>,
pub figi: Option<String>,
pub cusip: Option<String>,
pub outputsize: Option<i64>,
pub exchange: Option<String>,
pub mic_code: Option<String>,
pub country: Option<String>,
pub type: Option<String>,
pub timezone: Option<String>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub date: Option<String>,
pub order: Option<String>,
pub prepost: Option<bool>,
pub format: Option<String>,
pub delimiter: Option<String>,
pub dp: Option<i64>,
pub previous_close: Option<bool>,
pub adjust: Option<String>,
pub series_type: Option<String>,
pub time_period: Option<i64>,
pub include_ohlc: Option<bool>,
}Expand description
struct for passing parameters to the method get_time_series_min
Fields
interval: StringInterval between two consecutive points in time series
symbol: Option<String>Symbol ticker of the instrument. E.g. AAPL, EUR/USD, ETH/BTC, …
isin: Option<String>Filter by international securities identification number (ISIN)
figi: Option<String>The FIGI of an instrument for which data is requested
cusip: Option<String>The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section
outputsize: Option<i64>Number of data points to retrieve. Supports values in the range from 1 to 5000. Default 30 when no date parameters are set, otherwise set to maximum
exchange: Option<String>Exchange where instrument is traded
mic_code: Option<String>Market Identifier Code (MIC) under ISO 10383 standard
country: Option<String>The country where the instrument is traded, e.g., United States or US
type: Option<String>The asset class to which the instrument belongs
timezone: Option<String>Timezone at which output datetime will be displayed. Supports:
- 1.
Exchangefor local exchange time - 2.
UTCfor datetime at universal UTC standard - 3. Timezone name according to the IANA Time Zone Database. E.g.
America/New_York,Asia/Singapore. Full list of timezones can be found <a href="https://en.wikipedia.org/wiki/List_of_tz_database_time_zones" target="blank">here
start_date: Option<String>Can be used separately and together with end_date. Format 2006-01-02 or 2006-01-02T15:04:05 Default location:
- Forex and Cryptocurrencies -
UTC - Stocks - where exchange is located (e.g. for AAPL it will be
America/New_York)
timezone parameter is provided.If
timezone is given then, start_date and end_date will be used in the specified location Examples: - 1.
&symbol=AAPL&start_date=2019-08-09T15:50:00&…
Returns all records starting from 2019-08-09T15:50:00 New York time up to current date - 2.
&symbol=EUR/USD&timezone=Asia/Singapore&start_date=2019-08-09T15:50:00&…
Returns all records starting from 2019-08-09T15:50:00 Singapore time up to current date - 3.
&symbol=ETH/BTC&timezone=Europe/Zurich&start_date=2019-08-09T15:50:00&end_date=2019-08-09T15:55:00&…
Returns all records starting from 2019-08-09T15:50:00 Zurich time up to 2019-08-09T15:55:00
end_date: Option<String>The ending date and time for data selection, see start_date description for details.
date: Option<String>Specifies the exact date to get the data for. Could be the exact date, e.g. 2021-10-27, or in human language today or yesterday
order: Option<String>Sorting order of the output
prepost: Option<bool>Returns quotes that include pre-market and post-market data. Only for Pro and above plans. Available at the 1min, 5min, 15min, and 30min intervals for US equities. Open, high, low, close values are supplied without volume
format: Option<String>The format of the response data
delimiter: Option<String>The separator used in the CSV response data
dp: Option<i64>Specifies the number of decimal places for floating values. Should be in range [0, 11] inclusive. By default, the number of decimal places is automatically determined based on the values provided
previous_close: Option<bool>A boolean parameter to include the previous closing price in the time_series data. If true, adds previous bar close price value to the current object
adjust: Option<String>Adjusting mode for prices
series_type: Option<String>Price type on which technical indicator is calculated
time_period: Option<i64>Number of periods to average over. Takes values in the range from 1 to 800
include_ohlc: Option<bool>Specify if OHLC values should be added in the output
Implementations
Sourceimpl GetTimeSeriesMinParams
impl GetTimeSeriesMinParams
Sourcepub fn builder() -> GetTimeSeriesMinParamsBuilder
pub fn builder() -> GetTimeSeriesMinParamsBuilder
Create a new builder for this parameter struct