GetTimeSeriesMinParamsBuilder

Struct GetTimeSeriesMinParamsBuilder 

pub struct GetTimeSeriesMinParamsBuilder { /* private fields */ }
Implementations

Source

impl GetTimeSeriesMinParamsBuilder

pub fn interval(self, interval: impl Into<String>) -> Self

Interval between two consecutive points in time series

pub fn symbol(self, symbol: impl Into<String>) -> Self

Symbol ticker of the instrument. E.g. AAPL, EUR/USD, ETH/BTC, …

pub fn isin(self, isin: impl Into<String>) -> Self

Filter by international securities identification number (ISIN)

pub fn figi(self, figi: impl Into<String>) -> Self

The FIGI of an instrument for which data is requested

pub fn cusip(self, cusip: impl Into<String>) -> Self

The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section

pub fn outputsize(self, outputsize: i64) -> Self

Number of data points to retrieve. Supports values in the range from 1 to 5000. Default 30 when no date parameters are set, otherwise set to maximum

pub fn exchange(self, exchange: impl Into<String>) -> Self

Exchange where instrument is traded

pub fn mic_code(self, mic_code: impl Into<String>) -> Self

Market Identifier Code (MIC) under ISO 10383 standard

pub fn country(self, country: impl Into<String>) -> Self

The country where the instrument is traded, e.g., United States or US

pub fn type(self, type: impl Into<String>) -> Self

The asset class to which the instrument belongs

pub fn timezone(self, timezone: impl Into<String>) -> Self

Timezone at which output datetime will be displayed. Supports:

  • 1. Exchange for local exchange time
  • 2. UTC for datetime at universal UTC standard
  • 3. Timezone name according to the IANA Time Zone Database. E.g. America/New_York, Asia/Singapore. Full list of timezones can be found <a href="https://en.wikipedia.org/wiki/List_of_tz_database_time_zones" target="blank">here
Take note that the IANA Timezone name is case-sensitive

pub fn start_date(self, start_date: impl Into<String>) -> Self

Can be used separately and together with end_date. Format 2006-01-02 or 2006-01-02T15:04:05 Default location:

  • Forex and Cryptocurrencies - UTC
  • Stocks - where exchange is located (e.g. for AAPL it will be America/New_York)
Both parameters take into account if timezone parameter is provided.
If timezone is given then, start_date and end_date will be used in the specified location Examples:
  • 1. &symbol=AAPL&start_date=2019-08-09T15:50:00&…
    Returns all records starting from 2019-08-09T15:50:00 New York time up to current date
  • 2. &symbol=EUR/USD&timezone=Asia/Singapore&start_date=2019-08-09T15:50:00&…
    Returns all records starting from 2019-08-09T15:50:00 Singapore time up to current date
  • 3. &symbol=ETH/BTC&timezone=Europe/Zurich&start_date=2019-08-09T15:50:00&end_date=2019-08-09T15:55:00&…
    Returns all records starting from 2019-08-09T15:50:00 Zurich time up to 2019-08-09T15:55:00

pub fn end_date(self, end_date: impl Into<String>) -> Self

The ending date and time for data selection, see start_date description for details.

pub fn date(self, date: impl Into<String>) -> Self

Specifies the exact date to get the data for. Could be the exact date, e.g. 2021-10-27, or in human language today or yesterday

pub fn order(self, order: impl Into<String>) -> Self

Sorting order of the output

pub fn prepost(self, prepost: bool) -> Self

Returns quotes that include pre-market and post-market data. Only for Pro and above plans. Available at the 1min, 5min, 15min, and 30min intervals for US equities. Open, high, low, close values are supplied without volume

pub fn format(self, format: impl Into<String>) -> Self

The format of the response data

pub fn delimiter(self, delimiter: impl Into<String>) -> Self

The separator used in the CSV response data

pub fn dp(self, dp: i64) -> Self

Specifies the number of decimal places for floating values. Should be in range [0, 11] inclusive. By default, the number of decimal places is automatically determined based on the values provided

pub fn previous_close(self, previous_close: bool) -> Self

A boolean parameter to include the previous closing price in the time_series data. If true, adds previous bar close price value to the current object

pub fn adjust(self, adjust: impl Into<String>) -> Self

Adjusting mode for prices

pub fn series_type(self, series_type: impl Into<String>) -> Self

Price type on which technical indicator is calculated

pub fn time_period(self, time_period: i64) -> Self

Number of periods to average over. Takes values in the range from 1 to 800

pub fn include_ohlc(self, include_ohlc: bool) -> Self

Specify if OHLC values should be added in the output

pub fn build(self) -> GetTimeSeriesMinParams

Build the parameter struct