pub struct CashFlowStruct {
pub fiscal_date: Option<String>,
pub quarter: Option<String>,
pub year: Option<i64>,
pub operating_activities: Option<Box<CashFlowStructOperatingActivities>>,
pub investing_activities: Option<Box<CashFlowStructInvestingActivities>>,
pub financing_activities: Option<Box<CashFlowStructFinancingActivities>>,
pub end_cash_position: Option<f64>,
pub income_tax_paid: Option<f64>,
pub interest_paid: Option<f64>,
pub free_cash_flow: Option<f64>,
}Fields
fiscal_date: Option<String>Date of the cash flow release
quarter: Option<String>Fiscal quarter. Visible when &period=quarterly
year: Option<i64>Fiscal year
operating_activities: Option<Box<CashFlowStructOperatingActivities>>investing_activities: Option<Box<CashFlowStructInvestingActivities>>financing_activities: Option<Box<CashFlowStructFinancingActivities>>end_cash_position: Option<f64>Returns the amount of cash a company has when adding the change in cash and beginning cash balance for the current fiscal period
income_tax_paid: Option<f64>Refers to supplemental data about income tax paid
interest_paid: Option<f64>Refers to supplemental data about interest paid
free_cash_flow: Option<f64>Represents the cash a company generates after accounting for cash outflows to support operations and maintain its capital assets
Implementations
Sourceimpl CashFlowStruct
impl CashFlowStruct
pub fn new() -> CashFlowStruct