IncomeStatementBlock

Struct IncomeStatementBlock 

pub struct IncomeStatementBlock {
Show 22 fields pub fiscal_date: Option<String>, pub quarter: Option<i64>, pub year: Option<i64>, pub sales: Option<i64>, pub cost_of_goods: Option<i64>, pub gross_profit: Option<i64>, pub operating_expense: Option<Box<IncomeStatementBlockOperatingExpense>>, pub operating_income: Option<i64>, pub non_operating_interest: Option<Box<IncomeStatementBlockNonOperatingInterest>>, pub other_income_expense: Option<i64>, pub pretax_income: Option<i64>, pub income_tax: Option<i64>, pub net_income: Option<i64>, pub eps_basic: Option<f64>, pub eps_diluted: Option<f64>, pub basic_shares_outstanding: Option<i64>, pub diluted_shares_outstanding: Option<i64>, pub ebit: Option<i64>, pub ebitda: Option<i64>, pub net_income_continuous_operations: Option<i64>, pub minority_interests: Option<i64>, pub preferred_stock_dividends: Option<i64>,
}

Fields

fiscal_date: Option<String>

Date of the income statement release

quarter: Option<i64>

Fiscal quarter. Visible when &period=quarterly

year: Option<i64>

Fiscal year

sales: Option<i64>

Refers to total reported revenue

cost_of_goods: Option<i64>

Refers to cost of revenue

gross_profit: Option<i64>

Refers to net gross profit: sales - cost_of_goods

operating_expense: Option<Box<IncomeStatementBlockOperatingExpense>>operating_income: Option<i64>

Refers to net operating income: gross_profit - research_and_development - selling_general_and_administrative

non_operating_interest: Option<Box<IncomeStatementBlockNonOperatingInterest>>other_income_expense: Option<i64>

Refers to other incomes or expenses

pretax_income: Option<i64>

Refers to earnings before tax: operating_income + net_non_operating_interest - other_income_expense

income_tax: Option<i64>

Refers to a tax provision

net_income: Option<i64>

Refers to net income: pretax_income - income_tax

eps_basic: Option<f64>

Refers to earnings per share (EPS)

eps_diluted: Option<f64>

Refers to diluted earnings per share (EPS)

basic_shares_outstanding: Option<i64>

Refers for the shares outstanding held by all its shareholders

diluted_shares_outstanding: Option<i64>

Refers to the total number of shares a company would have if all dilutive securities were exercised and converted into shares

ebit: Option<i64>

Refers to earnings before interest and taxes (EBIT) measure

ebitda: Option<i64>

Refers to EBITDA (earnings before interest, taxes, depreciation, and amortization) measure

net_income_continuous_operations: Option<i64>

Refers to the after-tax earnings that a business has generated from its operational activities

minority_interests: Option<i64>

Refers to amount of minority interests paid out

preferred_stock_dividends: Option<i64>

Refers to dividend that is allocated to and paid on a company’s preferred shares

Implementations