pub struct Quote {Show 26 fields
pub symbol: Option<String>,
pub name: Option<String>,
pub exchange: Option<String>,
pub mic_code: Option<String>,
pub currency: Option<String>,
pub datetime: Option<String>,
pub timestamp: Option<i64>,
pub last_quote_at: Option<i64>,
pub open: Option<String>,
pub high: Option<String>,
pub low: Option<String>,
pub close: Option<String>,
pub volume: Option<String>,
pub previous_close: Option<String>,
pub change: Option<String>,
pub percent_change: Option<String>,
pub average_volume: Option<String>,
pub rolling_1d_change: Option<String>,
pub rolling_7d_change: Option<String>,
pub rolling_change: Option<String>,
pub is_market_open: Option<bool>,
pub fifty_two_week: Option<Box<QuoteFiftyTwoWeek>>,
pub extended_change: Option<String>,
pub extended_percent_change: Option<String>,
pub extended_price: Option<String>,
pub extended_timestamp: Option<String>,
}Fields
symbol: Option<String>Symbol passed
name: Option<String>Name of the instrument
exchange: Option<String>Exchange where instrument is traded
mic_code: Option<String>Market identifier code (MIC) under ISO 10383 standard. Available for stocks, ETFs, mutual funds, bonds
currency: Option<String>Currency in which the equity is denominated. Available for stocks, ETFs, mutual funds, bonds
datetime: Option<String>Datetime in defined timezone referring to when the bar with specified interval was opened
timestamp: Option<i64>Unix timestamp representing the opening candle of the specified interval
last_quote_at: Option<i64>Unix timestamp of last minute candle
open: Option<String>Price at the opening of current bar
high: Option<String>Highest price which occurred during the current bar
low: Option<String>Lowest price which occurred during the current bar
close: Option<String>Close price at the end of the bar
volume: Option<String>Trading volume during the bar. Available not for all instrument types
previous_close: Option<String>Close price at the end of the previous bar
change: Option<String>Close - previous_close
percent_change: Option<String>(Close - previous_close) / previous_close * 100
average_volume: Option<String>Average volume of the specified period. Available not for all instrument types
rolling_1d_change: Option<String>Percent change in price between the current and the backward one, where period is 1 day. Available for crypto
rolling_7d_change: Option<String>Percent change in price between the current and the backward one, where period is 7 days. Available for crypto
rolling_change: Option<String>Percent change in price between the current and the backward one, where period specified in request param rolling_period. Available for crypto
is_market_open: Option<bool>True if market is open; false if closed
fifty_two_week: Option<Box<QuoteFiftyTwoWeek>>extended_change: Option<String>Diff between the regular close price and the latest extended price. Displayed only if prepost is true
extended_percent_change: Option<String>Percent change in price between the regular close price and the latest extended price. Displayed only if prepost is true
extended_price: Option<String>Latest extended price. Displayed only if prepost is true
extended_timestamp: Option<String>Unix timestamp of the last extended price. Displayed only if prepost is true