pub struct TechnicalIndicatorsDataValue {
pub enable: Option<bool>,
pub full_name: Option<String>,
pub description: Option<String>,
pub type: Option<String>,
pub overlay: Option<bool>,
pub output_values: Option<Box<TechnicalIndicatorsResponseMacdOutputValues>>,
pub parameters: Option<Box<TechnicalIndicatorsResponseMacdParameters>>,
pub tinting: Option<Box<TechnicalIndicatorsResponseMacdTinting>>,
}Fields
enable: Option<bool>If the indicator is tested, approved and is recommended for use returns true, otherwise returns false
full_name: Option<String>Full indicator name
description: Option<String>Brief description of the indicator
type: Option<String>Group to which indicator belongs to
overlay: Option<bool>If indicator should be plotted over price bars returns true, otherwise returns false
output_values: Option<Box<TechnicalIndicatorsResponseMacdOutputValues>>parameters: Option<Box<TechnicalIndicatorsResponseMacdParameters>>tinting: Option<Box<TechnicalIndicatorsResponseMacdTinting>>Implementations
Sourceimpl TechnicalIndicatorsDataValue
impl TechnicalIndicatorsDataValue
pub fn new() -> TechnicalIndicatorsDataValue