pub struct TechnicalIndicatorsResponseMacdParameter {
pub default: Option<i64>,
pub max_range: Option<i64>,
pub min_range: Option<i64>,
pub range: Option<Vec<String>>,
pub type: Option<String>,
}Expand description
TechnicalIndicatorsResponseMacdParameter : Input parameter name. Example values: series_type, fast_period, slow_period, time_period, signal_period
Fields
default: Option<i64>Specifies parameter value set by default
max_range: Option<i64>If the parameter has upper bound in order to ensure correct calculation
min_range: Option<i64>If the parameter has lower bound in order to ensure correct calculation
range: Option<Vec<String>>An array of available parameter values
type: Option<String>Type of parameter might be string, int, float or array
Implementations
Sourceimpl TechnicalIndicatorsResponseMacdParameter
impl TechnicalIndicatorsResponseMacdParameter
Sourcepub fn new() -> TechnicalIndicatorsResponseMacdParameter
pub fn new() -> TechnicalIndicatorsResponseMacdParameter
Input parameter name. Example values: series_type, fast_period, slow_period, time_period, signal_period