pub struct TechnicalIndicatorsResponseMacdTinting {
pub display: Option<String>,
pub color: Option<String>,
pub transparency: Option<f64>,
pub lower_bound: Option<Value>,
pub upper_bound: Option<Value>,
}Expand description
TechnicalIndicatorsResponseMacdTinting : An array of tinting values used for proper indicator coloring
Fields
display: Option<String>How the tinting should be rendered
color: Option<String>Hex color code for the tinting
transparency: Option<f64>Transparency level, float value from 0 to 1
lower_bound: Option<Value>Lower bound of tinting, can be a number or a return parameter name
upper_bound: Option<Value>Upper bound of tinting, can be a number or a return parameter name
Implementations
Sourceimpl TechnicalIndicatorsResponseMacdTinting
impl TechnicalIndicatorsResponseMacdTinting
Sourcepub fn new() -> TechnicalIndicatorsResponseMacdTinting
pub fn new() -> TechnicalIndicatorsResponseMacdTinting
An array of tinting values used for proper indicator coloring