pub struct TimeSeriesExpMeta {
pub symbol: Option<String>,
pub interval: Option<String>,
pub currency: Option<String>,
pub exchange_timezone: Option<String>,
pub exchange: Option<String>,
pub mic_code: Option<String>,
pub type: Option<String>,
pub indicator: Option<Box<TimeSeriesExpMetaIndicator>>,
}Expand description
TimeSeriesExpMeta : Json object with request general information
Fields
symbol: Option<String>The ticker symbol of an instrument for which data was requested.
interval: Option<String>The time gap between consecutive data points.
currency: Option<String>The currency of a traded instrument.
exchange_timezone: Option<String>The timezone of the exchange where the instrument is traded.
exchange: Option<String>The exchange name where the instrument is traded.
mic_code: Option<String>The Market Identifier Code (MIC) of the exchange where the instrument is traded.
type: Option<String>The asset class to which the instrument belongs.
indicator: Option<Box<TimeSeriesExpMetaIndicator>>Implementations
Sourceimpl TimeSeriesExpMeta
impl TimeSeriesExpMeta
Sourcepub fn new() -> TimeSeriesExpMeta
pub fn new() -> TimeSeriesExpMeta
Json object with request general information