pub struct GetExchangeRateParams {
pub symbol: String,
pub date: Option<String>,
pub format: Option<String>,
pub delimiter: Option<String>,
pub dp: Option<i64>,
pub timezone: Option<String>,
}Expand description
struct for passing parameters to the method get_exchange_rate
Fields
symbol: StringThe currency pair you want to request can be either forex or cryptocurrency. Slash(/) delimiter is used. E.g. EUR/USD or BTC/ETH will be correct
date: Option<String>If not null, will use exchange rate from a specific date or time. Format 2006-01-02 or 2006-01-02T15:04:05. Is set in the local exchange time zone, use timezone parameter to specify a specific time zone
format: Option<String>Value can be JSON or CSV. Default JSON
delimiter: Option<String>Specify the delimiter used when downloading the CSV file. Default semicolon ;
dp: Option<i64>The number of decimal places for the data
timezone: Option<String>Timezone at which output datetime will be displayed. Supports:
- 1.
Exchangefor local exchange time - 2.
UTCfor datetime at universal UTC standard - 3. Timezone name according to the IANA Time Zone Database. E.g.
America/New_York,Asia/Singapore. Full list of timezones can be found <a href="https://en.wikipedia.org/wiki/List_of_tz_database_time_zones" target="blank">here.
Implementations
Sourceimpl GetExchangeRateParams
impl GetExchangeRateParams
Sourcepub fn builder() -> GetExchangeRateParamsBuilder
pub fn builder() -> GetExchangeRateParamsBuilder
Create a new builder for this parameter struct