pub async fn get_cryptocurrency_exchanges(
configuration: &Configuration,
params: GetCryptocurrencyExchangesParams,
) -> Result<GetCryptocurrencyExchangesResponse, Error<GetCryptocurrencyExchangesError>>Expand description
The cryptocurrency exchanges endpoint provides a daily updated list of available cryptocurrency exchanges. It returns an array containing details about each exchange, such as exchange names and identifiers.