pub async fn get_etfs_list(
configuration: &Configuration,
params: GetEtfsListParams,
) -> Result<GetEtfsListResponse, Error<GetEtfsListError>>Expand description
The ETFs directory endpoint provides a daily updated list of exchange-traded funds, sorted by total assets in descending order. This endpoint is useful for retrieving comprehensive ETF data, including fund names and asset values, to assist users in quickly identifying the ETFs available.