pub async fn get_funds(
configuration: &Configuration,
params: GetFundsParams,
) -> Result<GetFundsResponse, Error<GetFundsError>>Expand description
The funds endpoint provides a daily updated list of available investment funds. It returns an array containing detailed information about each fund, including identifiers, names, and other relevant attributes.