get_intervals

Function get_intervals 

pub async fn get_intervals(
    configuration: &Configuration,
) -> Result<GetIntervals200Response, Error<GetIntervalsError>>
The intervals endpoint provides a list of supported time intervals that can be used for querying financial data.