GetStocksParams

Struct GetStocksParams 

pub struct GetStocksParams {
Show 13 fields pub symbol: Option<String>, pub figi: Option<String>, pub isin: Option<String>, pub cusip: Option<String>, pub cik: Option<String>, pub exchange: Option<String>, pub mic_code: Option<String>, pub country: Option<String>, pub type: Option<String>, pub format: Option<String>, pub delimiter: Option<String>, pub show_plan: Option<bool>, pub include_delisted: Option<bool>,
}
struct for passing parameters to the method get_stocks

Fields

symbol: Option<String>

The ticker symbol of an instrument for which data is requested

figi: Option<String>

Filter by financial instrument global identifier (FIGI)

isin: Option<String>

Filter by international securities identification number (ISIN)

cusip: Option<String>

The CUSIP of an instrument for which data is requested. CUSIP access is activating in the <a href="https://twelvedata.com/account/add-ons">Add-ons section

cik: Option<String>

The CIK of an instrument for which data is requested

exchange: Option<String>

Filter by exchange name

mic_code: Option<String>

Filter by market identifier code (MIC) under ISO 10383 standard

country: Option<String>

Filter by country name or alpha code, e.g., United States or US

type: Option<String>

The asset class to which the instrument belongs

format: Option<String>

The format of the response data

delimiter: Option<String>

The separator used in the CSV response data

show_plan: Option<bool>

Adds info on which plan symbol is available

include_delisted: Option<bool>

Include delisted identifiers

Implementations

Source

impl GetStocksParams

pub fn builder() -> GetStocksParamsBuilder

Create a new builder for this parameter struct