pub struct CashFlowStructFinancingActivities {
pub long_term_debt_issuance: Option<f64>,
pub long_term_debt_payments: Option<f64>,
pub short_term_debt_issuance: Option<f64>,
pub common_stock_issuance: Option<f64>,
pub common_stock_repurchase: Option<f64>,
pub common_dividends: Option<f64>,
pub other_financing_charges: Option<f64>,
pub financing_cash_flow: Option<f64>,
}Expand description
CashFlowStructFinancingActivities : Financing activities section
Fields
long_term_debt_issuance: Option<f64>Refers to the issuance of any financial obligations that extend beyond a 12 months period
long_term_debt_payments: Option<f64>Refers to the payments of any financial obligations that extend beyond a 12 months period
short_term_debt_issuance: Option<f64>Refers to the issuance of any financial obligations that are expected to be paid off within a year
common_stock_issuance: Option<f64>Represents a transaction whereby a company issues its own shares to the marketplace
common_stock_repurchase: Option<f64>Represents a transaction whereby a company buys back its own shares from the marketplace
common_dividends: Option<f64>Returns value of payment doled out by a company to its stockholders in the form of periodic distributions of cash
other_financing_charges: Option<f64>Represents other financing charges
financing_cash_flow: Option<f64>Returns cash flow from financing activities (CFF), which shows the net flows of cash that are used to fund the company
Implementations
Sourceimpl CashFlowStructFinancingActivities
impl CashFlowStructFinancingActivities
Sourcepub fn new() -> CashFlowStructFinancingActivities
pub fn new() -> CashFlowStructFinancingActivities
Financing activities section