pub struct CashFlowStructOperatingActivities {
pub net_income: Option<f64>,
pub depreciation: Option<f64>,
pub deferred_taxes: Option<f64>,
pub stock_based_compensation: Option<f64>,
pub other_non_cash_items: Option<f64>,
pub accounts_receivable: Option<f64>,
pub accounts_payable: Option<f64>,
pub other_assets_liabilities: Option<f64>,
pub operating_cash_flow: Option<f64>,
}Expand description
CashFlowStructOperatingActivities : Operating activities section
Fields
net_income: Option<f64>Returns net income (NI). Calculated as sales minus cost of goods sold
depreciation: Option<f64>Represents depreciation and amortization measure
deferred_taxes: Option<f64>Stands for taxes that are owed but are not due to be paid until a future date
stock_based_compensation: Option<f64>Refers to share-based compensation as the way of paying employees, executives, and directors of a company with equity in the business
other_non_cash_items: Option<f64>Represents other non-cash items
accounts_receivable: Option<f64>Represents the balance of money due to a firm for goods or services delivered or used but not yet paid for by customers
accounts_payable: Option<f64>Refers to an account within the general ledger that represents an obligation to pay off a short-term debt to creditors or suppliers
other_assets_liabilities: Option<f64>Represents cumulative changes in inventory, other current assets, other current liabilities, and other working capital
operating_cash_flow: Option<f64>Returns operating cash flow (OCF) measure representing a total amount of cash generated by company’s normal business operations
Implementations
Sourceimpl CashFlowStructOperatingActivities
impl CashFlowStructOperatingActivities
Sourcepub fn new() -> CashFlowStructOperatingActivities
pub fn new() -> CashFlowStructOperatingActivities
Operating activities section